@@ -231,86 +231,6 @@ prefs_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 }
 
 
-static void
-show_kill_dialog_toggled (GtkToggleButton *button, gpointer data)
-{
-    ProcmanApp *app = static_cast<ProcmanApp *>(data);
-    GSettings *settings = app->settings;
-
-    gboolean toggled;
-
-    toggled = gtk_toggle_button_get_active (button);
-
-    g_settings_set_boolean (settings, "kill-dialog", toggled);
-}
-
-
-
-static void
-solaris_mode_toggled(GtkToggleButton *button, gpointer data)
-{
-    ProcmanApp *app = static_cast<ProcmanApp *>(data);
-    GSettings *settings = app->settings;
-
-    gboolean toggled;
-    toggled = gtk_toggle_button_get_active(button);
-    g_settings_set_boolean(settings, procman::settings::solaris_mode.c_str(), toggled);
-}
-
-static void
-draw_stacked_toggled(GtkToggleButton *button, gpointer data)
-{
-    ProcmanApp *app = static_cast<ProcmanApp *>(data);
-    GSettings *settings = app->settings;
-
-    gboolean toggled;
-    toggled = gtk_toggle_button_get_active(button);
-    g_settings_set_boolean(settings, procman::settings::draw_stacked.c_str(), toggled);
-}
-
-
-static void
-network_in_bits_toggled(GtkToggleButton *button, gpointer data)
-{
-    ProcmanApp *app = static_cast<ProcmanApp *>(data);
-    GSettings *settings = app->settings;
-
-    gboolean toggled;
-    toggled = gtk_toggle_button_get_active(button);
-    g_settings_set_boolean(settings, procman::settings::network_in_bits.c_str(), toggled);
-}
-
-
-
-static void
-smooth_refresh_toggled(GtkToggleButton *button, gpointer data)
-{
-    ProcmanApp *app = static_cast<ProcmanApp *>(data);
-    GSettings *settings = app->settings;
-
-    gboolean toggled;
-
-    toggled = gtk_toggle_button_get_active(button);
-
-    g_settings_set_boolean(settings, SmoothRefresh::KEY.c_str(), toggled);
-}
-
-
-
-static void
-show_all_fs_toggled (GtkToggleButton *button, gpointer data)
-{
-    ProcmanApp *app = static_cast<ProcmanApp *>(data);
-    GSettings *settings = app->settings;
-
-    gboolean toggled;
-
-    toggled = gtk_toggle_button_get_active (button);
-
-    g_settings_set_boolean (settings, "show-all-fs", toggled);
-}
-
-
 class SpinButtonUpdater
 {
 public:
@@ -341,18 +261,15 @@ private:
     const string key;
 };
 
-
-
-
 static void
-field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+field_toggled (const gchar *gconf_parent, GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 {
     GtkTreeModel *model = static_cast<GtkTreeModel*>(data);
     GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
     GtkTreeIter iter;
     GtkTreeViewColumn *column;
     gboolean toggled;
-    GSettings *settings = g_settings_get_child (ProcmanApp::get()->settings, "proctree");
+    GSettings *settings = g_settings_get_child (ProcmanApp::get()->settings, gconf_parent);
     gchar *key;
     int id;
 
@@ -377,6 +294,18 @@ field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 
 }
 
+static void
+proc_field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+{
+    field_toggled("proctree", cell, path_str, data);
+}
+
+static void
+disk_field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+{
+    field_toggled("disktreenew", cell, path_str, data);
+}
+
 static void
 create_field_page(GtkBuilder* builder, GtkWidget *tree, const gchar *widgetname)
 {
@@ -385,8 +314,12 @@ create_field_page(GtkBuilder* builder, GtkWidget *tree, const gchar *widgetname)
     GtkListStore *model;
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell;
+    gchar *full_widgetname;
+
+    full_widgetname = g_strdup_printf ("%s_columns", widgetname);
+    treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, full_widgetname));
+    g_free (full_widgetname);
 
-    treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, widgetname));
     model = gtk_list_store_new (3, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_POINTER);
 
     gtk_tree_view_set_model (GTK_TREE_VIEW(treeview), GTK_TREE_MODEL(model));
@@ -399,7 +332,11 @@ create_field_page(GtkBuilder* builder, GtkWidget *tree, const gchar *widgetname)
     gtk_tree_view_column_set_attributes (column, cell,
                                          "active", 0,
                                          NULL);
-    g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (field_toggled), model);
+    if(!g_strcmp0(widgetname, "proctree")) 
+        g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (proc_field_toggled), model);
+    else if(!g_strcmp0(widgetname, "disktreenew")) 
+        g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (disk_field_toggled), model);
+
     gtk_tree_view_column_set_clickable (column, TRUE);
     gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
@@ -496,33 +433,18 @@ procdialog_create_preferences_dialog (ProcmanApp *app)
                       G_CALLBACK (SBU::callback), &interval_updater);
 
     smooth_button = GTK_WIDGET (gtk_builder_get_object (builder, "smooth_button"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(smooth_button),
-                                 g_settings_get_boolean(app->settings,
-                                                        SmoothRefresh::KEY.c_str()));
-    g_signal_connect(G_OBJECT(smooth_button), "toggled",
-                     G_CALLBACK(smooth_refresh_toggled), app);
+    g_settings_bind(app->settings, SmoothRefresh::KEY.c_str(), smooth_button, "active", G_SETTINGS_BIND_DEFAULT);
 
     check_button = GTK_WIDGET (gtk_builder_get_object (builder, "check_button"));
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button),
-                                  app->config.show_kill_warning);
-    g_signal_connect (G_OBJECT (check_button), "toggled",
-                      G_CALLBACK (show_kill_dialog_toggled), app);
+    g_settings_bind(app->settings, "kill-dialog", check_button, "active", G_SETTINGS_BIND_DEFAULT);
 
     GtkWidget *solaris_button = GTK_WIDGET (gtk_builder_get_object (builder, "solaris_button"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(solaris_button),
-                                 g_settings_get_boolean(app->settings,
-                                                        procman::settings::solaris_mode.c_str()));
-    g_signal_connect(G_OBJECT(solaris_button), "toggled",
-                     G_CALLBACK(solaris_mode_toggled), app);
+    g_settings_bind(app->settings, procman::settings::solaris_mode.c_str(), solaris_button, "active", G_SETTINGS_BIND_DEFAULT);
 
     GtkWidget *draw_stacked_button = GTK_WIDGET (gtk_builder_get_object (builder, "draw_stacked_button"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(draw_stacked_button),
-                                 g_settings_get_boolean(app->settings,
-                                                        procman::settings::draw_stacked.c_str()));
-    g_signal_connect(G_OBJECT(draw_stacked_button), "toggled",
-                     G_CALLBACK(draw_stacked_toggled), app);
+    g_settings_bind(app->settings, procman::settings::draw_stacked.c_str(), draw_stacked_button, "active", G_SETTINGS_BIND_DEFAULT);
 
-    create_field_page (builder, app->tree, "processes_columns_treeview");
+    create_field_page (builder, app->tree, "proctree");
 
     update = (gfloat) app->config.graph_update_interval;
     adjustment = (GtkAdjustment *) gtk_adjustment_new(update / 1000.0, 0.25,
@@ -534,12 +456,7 @@ procdialog_create_preferences_dialog (ProcmanApp *app)
                       &graph_interval_updater);
 
     GtkWidget *bits_button = GTK_WIDGET (gtk_builder_get_object (builder, "bits_button"));
-
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bits_button),
-                                 g_settings_get_boolean(app->settings,
-                                                        procman::settings::network_in_bits.c_str()));
-    g_signal_connect(G_OBJECT(bits_button), "toggled",
-                     G_CALLBACK(network_in_bits_toggled), app);
+    g_settings_bind(app->settings, procman::settings::network_in_bits.c_str(), bits_button, "active", G_SETTINGS_BIND_DEFAULT);
 
     update = (gfloat) app->config.disks_update_interval;
     adjustment = (GtkAdjustment *) gtk_adjustment_new (update / 1000.0, 1.0,
@@ -552,12 +469,9 @@ procdialog_create_preferences_dialog (ProcmanApp *app)
 
 
     check_button = GTK_WIDGET (gtk_builder_get_object (builder, "all_devices_check"));
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button),
-                                  app->config.show_all_fs);
-    g_signal_connect (G_OBJECT (check_button), "toggled",
-                      G_CALLBACK (show_all_fs_toggled), app);
+    g_settings_bind(app->settings, "show-all-fs", check_button, "active", G_SETTINGS_BIND_DEFAULT);
 
-    create_field_page (builder, app->disk_list, "devices_columns_treeview");
+    create_field_page (builder, app->disk_list, "disktreenew");
 
     gtk_widget_show_all (prefs_dialog);
     g_signal_connect (G_OBJECT (prefs_dialog), "response",
