@@ -70,24 +70,6 @@ ProcInfo* ProcInfo::find(pid_t pid)
 }
 
 
-
-static void
-set_proctree_reorderable(ProcmanApp *app)
-{
-    GList *columns, *col;
-    GtkTreeView *proctree;
-
-    proctree = GTK_TREE_VIEW(app->tree);
-
-    columns = gtk_tree_view_get_columns (proctree);
-
-    for(col = columns; col; col = col->next)
-        gtk_tree_view_column_set_reorderable(static_cast<GtkTreeViewColumn*>(col->data), TRUE);
-
-    g_list_free(columns);
-}
-
-
 static void
 cb_columns_changed(GtkTreeView *treeview, gpointer data)
 {
@@ -172,29 +154,6 @@ proctable_get_columns_order(GtkTreeView *treeview)
     return order;
 }
 
-void
-cb_proctable_column_resized(GtkWidget *widget)
-{
-    GtkTreeViewColumn *column = GTK_TREE_VIEW_COLUMN(widget);
-    gint width;
-    gchar *key;
-    int id;
-    GSettings *settings;
-    gint saved_width;
-
-    settings = g_settings_get_child (ProcmanApp::get()->settings, "proctree");
-    id = gtk_tree_view_column_get_sort_column_id (column);
-    width = gtk_tree_view_column_get_width (column);
-    key = g_strdup_printf ("col-%d-width", id);
-
-    g_settings_get (settings, key, "i", &saved_width);
-    if (saved_width!=width)
-    {
-        g_settings_set_int(settings, key, width);
-    }
-    g_free (key);
-}
-
 static gboolean
 search_equal_func(GtkTreeModel *model,
                   gint column,
@@ -234,7 +193,6 @@ proctable_new (ProcmanApp * const app)
     GtkTreeSelection *selection;
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell_renderer;
-
     const gchar *titles[] = {
         N_("Process Name"),
         N_("User"),
@@ -267,7 +225,7 @@ proctable_new (ProcmanApp * const app)
     };
 
     gint i;
-
+    GSettings * settings = g_settings_get_child (app->settings, "proctree");
     model = gtk_tree_store_new (NUM_COLUMNS,
                                 G_TYPE_STRING,      /* Process Name */
                                 G_TYPE_STRING,      /* User         */
@@ -326,15 +284,16 @@ proctable_new (ProcmanApp * const app)
                                          "text", COL_NAME,
                                          NULL);
     gtk_tree_view_column_set_title (column, _(titles[0]));
+
     gtk_tree_view_column_set_sort_column_id (column, COL_NAME);
     gtk_tree_view_column_set_resizable (column, TRUE);
     gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
     gtk_tree_view_column_set_min_width (column, 1);
-    g_signal_connect(G_OBJECT(column), "notify::width", G_CALLBACK(cb_proctable_column_resized), NULL);
+    gtk_tree_view_column_set_reorderable(column, TRUE);
+    g_signal_connect(G_OBJECT(column), "notify::width", G_CALLBACK(cb_column_resized), settings);
     gtk_tree_view_append_column (GTK_TREE_VIEW (proctree), column);
     gtk_tree_view_set_expander_column (GTK_TREE_VIEW (proctree), column);
 
-
     for (i = COL_USER; i <= COL_PRIORITY; i++) {
 
         GtkCellRenderer *cell;
@@ -346,10 +305,9 @@ proctable_new (ProcmanApp * const app)
         gtk_tree_view_column_set_title(col, _(titles[i]));
         gtk_tree_view_column_set_resizable(col, TRUE);
         gtk_tree_view_column_set_sort_column_id(col, i);
-        g_signal_connect(G_OBJECT(col), "notify::width", G_CALLBACK(cb_proctable_column_resized), NULL);
+        g_signal_connect(G_OBJECT(col), "notify::width", G_CALLBACK(cb_column_resized), settings);
         gtk_tree_view_column_set_reorderable(col, TRUE);
         gtk_tree_view_append_column(GTK_TREE_VIEW(proctree), col);
-
         // type
         switch (i) {
             case COL_MEMXSERVER:
@@ -441,10 +399,10 @@ proctable_new (ProcmanApp * const app)
                 break;
         }
 
+        gtk_tree_view_column_set_sizing(col, GTK_TREE_VIEW_COLUMN_FIXED);
         // sizing
         switch (i) {
             case COL_ARGS:
-                gtk_tree_view_column_set_sizing(col, GTK_TREE_VIEW_COLUMN_FIXED);
                 gtk_tree_view_column_set_min_width(col, 150);
                 break;
             default:
@@ -452,13 +410,9 @@ proctable_new (ProcmanApp * const app)
                 break;
         }
     }
-
     app->tree = proctree;
 
-    set_proctree_reorderable(app);
-
     procman_get_tree_state (app->settings, proctree, "proctree");
-
     /* Override column settings by hiding this column if it's meaningless: */
     if (!can_show_security_context_column ()) {
         GtkTreeViewColumn *column;
